@@ -18,7 +18,8 @@ fn main() {
     let r = running.clone();
     ctrlc::set_handler(move || {
         r.store(false, Ordering::SeqCst);
-    }).expect("Error setting Ctrl-C handler");
+    })
+    .expect("Error setting Ctrl-C handler");
     println!("Waiting for Ctrl-C...");
     while running.load(Ordering::SeqCst) {
         thread::sleep(time::Duration::from_millis(10));
